// ============================================================================
// Project:	Deductive Database
// Filename:	max.h
// Purpose:	Maximum-Function
// Last Change:	01.08.2017
// Language:	C++
// EMail:	brass@informatik.uni-halle.de
// WWW:		http://www.informatik.uni-halle.de/~brass/
// Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
// Copyright:	(c) 2015-2017 by Stefan Brass
// License:	See file "LICENSE" for copying conditions.
// Note:	There is no warranty at all - this code may contain bugs.
// ============================================================================


/**
 * \file  max.h
 * \brief Maximum function (as template or macro).
 */


//=============================================================================
// Include File Frame:
//=============================================================================

#ifndef	MAX_INCLUDED
#define MAX_INCLUDED


//=============================================================================
// Used Types and Macros:
//=============================================================================

#ifndef VER_INCLUDED
#include "../base/ver.h"
#endif

#ifndef CHECK_INCLUDED
#include "../base/check.h"
#endif


//=============================================================================
// Template Function:
//=============================================================================


//-----------------------------------------------------------------------------
// Maximum:
//-----------------------------------------------------------------------------

/**
 * \def   MAX(X, Y)
 * \brief Maximum of \a X and \a Y.
 *
 * Note: The maximum function might be implemented as a macro.
 * Therefore, the arguments should have no side effects.
 */

//#define MAX(X,Y)	(((X)>=(Y))?(X):(Y))

/**
 * Maximum of \a X and \a Y.
 *
 * This was a macro, but I converted it to an inline function template.
 * It returns the larger of the two arguments.
 */

template<class T>
inline T MAX(T x, T y) {
	if(x >= y)
		return x;
	else
		return y;
}


//=============================================================================
// End of Include File:
//=============================================================================

#endif

