// ============================================================================
// Project:	Deductive Database
// Filename:	argtype.h
// Purpose:	Argument types for predicates (int, atom, string)
// Last Change:	04.08.2017
// Language:	C++
// EMail:	brass@informatik.uni-halle.de
// WWW:		http://www.informatik.uni-halle.de/~brass/
// Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
// Copyright:	(c) 2015-2017 by Stefan Brass
// License:	See file "LICENSE" for copying conditions.
// Note:	There is no warranty at all - this code may contain bugs.
// ============================================================================


/**
 * \file  argtype.h
 * \brief Enumeration type for types of predicate arguments
 */


//=============================================================================
// Include File Frame:
//=============================================================================

#ifndef	ARGTYPE_INCLUDED
#define ARGTYPE_INCLUDED

//=============================================================================
// Used Types and Macros:
//=============================================================================

#ifndef VER_INCLUDED
#include "../base/ver.h"
#endif

#ifndef STR_INCLUDED
#include "../base/str.h"
#endif

#ifndef CHECK_INCLUDED
#include "../base/check.h"
#endif

//=============================================================================
// Exported Types:
//=============================================================================

//-----------------------------------------------------------------------------
// argtype_t: Argument types for predicates.
//-----------------------------------------------------------------------------

/**
 * Enumeration type for argument types of database predicates.
 */

typedef enum argtype_enum {
	ARGTYPE_NULL,	/**< Argument type is undefined or unknown */
	ARGTYPE_INT,	/**< Argument is an integer, e.g. 123 */
	ARGTYPE_ATOM,	/**< Argument is a identifier with lowercase letter */
	ARGTYPE_STR,	/**< Argument is a string, e.g. 'abc' */
	ARGTYPE_ATOM_STR/**< Argument is atom or string, e.g. abc or 'abc' */
} argtype_t;

//=============================================================================
// Exported Functions:
//=============================================================================

//-----------------------------------------------------------------------------
// argtype_valid: Is the parameter a valid element of the enumeration type?
//-----------------------------------------------------------------------------

#if	VER_DEBUG
bool	argtype_valid(argtype_t argtype);
#endif

//-----------------------------------------------------------------------------
// argtype_name: String representation of this argument type.
//-----------------------------------------------------------------------------

//** String representation of this argument type */
str_t	argtype_name(argtype_t argtype);

//=============================================================================
// End of File:
//=============================================================================

#endif

