// ============================================================================
// Project:	Deductive Database
// Filename:	relsize.cpp
// Purpose:	Size measures for relation data structures.
// Last Change:	04.08.2017
// Language:	C++
// EMail:	brass@informatik.uni-halle.de
// WWW:		http://www.informatik.uni-halle.de/~brass/
// Address:	Feldschloesschen 15, D-06120 Halle (Saale), GERMANY
// Copyright:	(c) 2016-2017 by Stefan Brass
// License:	See file "LICENSE" for copying conditions.
// Note:	There is no warranty at all - this code may contain bugs.
// ============================================================================


//=============================================================================
// Interface:
//=============================================================================

#include "../base/ver.h"
#include "../base/str.h"
#include "../base/check.h"

#include "relsize.h"

//=============================================================================
// Exported Functions:
//=============================================================================

//-----------------------------------------------------------------------------
// relsize_valid: Is the parameter a valid element of the enumeration type?
//-----------------------------------------------------------------------------

#if	VER_DEBUG

bool	relsize_valid(relsize_t relsize)
{
	return(	relsize == RELSIZE_OBJ_SIZE         ||
		relsize == RELSIZE_HASHTAB_SIZE     ||
		relsize == RELSIZE_ENTRIES_USED     ||
		relsize == RELSIZE_BUCKET_SIZE      ||
		relsize == RELSIZE_BUCKET_BYTES     ||
		relsize == RELSIZE_TOTAL_BUCKETS    ||
		relsize == RELSIZE_OVERFLOW_BUCKETS
	);
}

#endif

//-----------------------------------------------------------------------------
// relsize_name: Name of size measure.
//-----------------------------------------------------------------------------

str_t relsize_name(relsize_t relsize)
{
	str_t name;
	
	switch(relsize) {
		case RELSIZE_OBJ_SIZE:
			name = "Object size";
			break;
		case RELSIZE_HASHTAB_SIZE:
			name = "Hash table size";
			break;
		case RELSIZE_ENTRIES_USED:
			name = "Used enties";
			break;
		case RELSIZE_BUCKET_SIZE:
			name = "Bucket size (entries)";
			break;
		case RELSIZE_BUCKET_BYTES:
			name = "Bucket size (bytes)";
			break;
		case RELSIZE_TOTAL_BUCKETS:
			name = "Total number of buckets";
			break;
		case RELSIZE_OVERFLOW_BUCKETS:
			name = "Number of overflow buckets";
			break;
		default:
			CHECK_IMPOSSIBLE("relsize_name: unknown size measure");
			name = "unknown size measure";
			break;
	}
	
	return name;
}

